Name:           apache-commons-configuration
Version:        2.11.0
Release:        %mkrel 2
Group:          Development/Java
Summary:        Read configuration data from a variety of sources

License:        Apache-2.0
BuildArch:      noarch
#ExclusiveArch:  %%{java_arches} noarch
URL:            https://commons.apache.org/proper/commons-configuration/
VCS:            https://github.com/apache/commons-configuration
Source0:        https://archive.apache.org/dist/commons/configuration/source/commons-configuration2-%{version}-src.tar.gz
Source1:        https://archive.apache.org/dist/commons/configuration/source/commons-configuration2-%{version}-src.tar.gz.asc
Source2:        https://downloads.apache.org/commons/KEYS

# Adapt to JEXL 3
Patch0:         %{name}-jexl3.patch

# Adapt to jakarta-servlet 5
Patch1:         %{name}-servlet5.patch

BuildRequires:  gnupg2
BuildRequires:  maven-local
BuildRequires:  mvn(commons-logging:commons-logging)
BuildRequires:  mvn(javax.servlet:servlet-api)
BuildRequires:  mvn(org.apache.commons:commons-lang3)
BuildRequires:  mvn(org.apache.commons:commons-parent:pom:)
BuildRequires:  mvn(org.apache.commons:commons-text)
BuildRequires:  mvn(org.apache.maven.plugins:maven-assembly-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-jar-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-surefire-plugin)
BuildRequires:  mvn(org.apiguardian:apiguardian-api)
BuildRequires:  mvn(org.codehaus.mojo:javacc-maven-plugin)

# Optional dependencies
BuildRequires:  mvn(com.fasterxml.jackson.core:jackson-databind)
BuildRequires:  mvn(commons-beanutils:commons-beanutils)
BuildRequires:  mvn(commons-codec:commons-codec)
BuildRequires:  mvn(commons-jxpath:commons-jxpath)
BuildRequires:  mvn(org.apache.commons:commons-jexl3)
BuildRequires:  mvn(org.apache.commons:commons-vfs2)
BuildRequires:  mvn(org.apache.logging.log4j:log4j-core)
BuildRequires:  mvn(xml-resolver:xml-resolver)

# Optional dependencies not available in Fedora
#BuildRequires:  mvn(org.springframework:spring-beans)
#BuildRequires:  mvn(org.springframework:spring-core)
#BuildRequires:  mvn(org.yaml:snakeyaml)

# Test dependencies
BuildRequires:  mvn(com.sun.mail:mailapi)
BuildRequires:  mvn(commons-io:commons-io)
BuildRequires:  mvn(org.hamcrest:hamcrest)
BuildRequires:  mvn(org.junit.jupiter:junit-jupiter)
BuildRequires:  mvn(org.mockito:mockito-core)
BuildRequires:  mvn(org.slf4j:slf4j-api)
BuildRequires:  mvn(org.slf4j:slf4j-nop)

# Test dependencies not available in Fedora
#BuildRequires:  mvn(org.apache.commons:commons-dbcp2)
#BuildRequires:  mvn(org.apache.commons:commons-pool2)
#BuildRequires:  mvn(org.dbunit:dbunit)
#BuildRequires:  mvn(org.hsqldb:hsqldb)
#BuildRequires:  mvn(org.slf4j:slf4j-ext)
#BuildRequires:  mvn(org.slf4j:slf4j-log4j12)
#BuildRequires:  mvn(org.springframework:spring-context)
#BuildRequires:  mvn(org.springframework:spring-test)

%description
The Commons Configuration software library provides a generic
configuration interface which enables a Java application to read
configuration data from a variety of sources.  Commons Configuration
provides typed access to single, and multi-valued configuration
parameters as demonstrated by the following code:

Double double = config.getDouble("number");
Integer integer = config.getInteger("number");

Configuration parameters may be loaded from the following sources:
- Properties files
- XML documents
- Windows INI files
- Property list files (plist)
- JNDI
- JDBC Datasource
- System properties
- Applet parameters
- Servlet parameters

Configuration objects are created using configuration builders.
Different configuration sources can be mixed using a
CombinedConfigurationBuilder and a CombinedConfiguration.  Additional
sources of configuration parameters can be created by using custom
configuration objects.  This customization can be achieved by extending
AbstractConfiguration or AbstractHierarchicalConfiguration.

%javadoc_package

%prep
%{gpgverify} --data=%{SOURCE0} --signature=%{SOURCE1} --keyring=%{SOURCE2}
%autosetup -n commons-configuration2-%{version}-src -p1

# Not needed for RPM builds
%pom_xpath_remove //pom:reporting
%pom_remove_plugin :apache-rat-plugin
%pom_remove_plugin :maven-checkstyle-plugin
%pom_remove_plugin :maven-javadoc-plugin
%pom_remove_plugin :maven-pmd-plugin
%pom_remove_plugin :maven-scm-publish-plugin
%pom_remove_plugin :spotbugs-maven-plugin

# The Spring framework is not available in Fedora
%pom_remove_dep org.springframework:spring-core
%pom_remove_dep org.springframework:spring-beans
%pom_remove_dep org.springframework:spring-context
%pom_remove_dep org.springframework:spring-test
rm -fr src/{main,test}/java/org/apache/commons/configuration2/spring

# snakeyaml is not available in Fedora
%pom_remove_dep org.yaml:snakeyaml
rm src/main/java/org/apache/commons/configuration2/YAMLConfiguration.java \
   src/test/java/org/apache/commons/configuration2/TestYAMLConfiguration.java

# Needed for the tests
%pom_add_dep org.apiguardian:apiguardian-api:1.1.2:test

# Some test dependencies are unavailable
%pom_remove_dep org.apache.commons:commons-dbcp2
%pom_remove_dep org.apache.commons:commons-pool2
%pom_remove_dep org.dbunit:dbunit
%pom_remove_dep org.hsqldb:hsqldb
%pom_remove_dep org.slf4j:slf4j-ext
%pom_remove_dep org.slf4j:slf4j-log4j12
rm src/test/java/org/apache/commons/configuration2/DatabaseConfigurationTestHelper.java
rm src/test/java/org/apache/commons/configuration2/TestDatabaseConfiguration.java
rm src/test/java/org/apache/commons/configuration2/event/TestDatabaseConfigurationEvents.java

# Update jakarta.mail to javax.mail
for f in \
 src/test/java/org/apache/commons/configuration2/TestDataConfiguration.java; do
  sed -i.orig 's/jakarta\.mail/javax.mail/g' $f
  touch -f $f.orig $f
  rm $f.orig
done

%build
%mvn_build -- -Dcommons.packageId=configuration -DargLine=

%install
%mvn_install

%files -f .mfiles
%doc README.md RELEASE-NOTES.txt
%license LICENSE.txt NOTICE.txt


%changelog
* Mon Jun 24 2024 daviddavid <daviddavid> 2.11.0-2.mga10
+ Revision: 2076477
- rebuild for missing pkgs

* Thu Jun 13 2024 daviddavid <daviddavid> 2.11.0-1.mga10
+ Revision: 2072951
- Version 2.11.0
- Drop dependency on snakeyaml

* Thu May 23 2024 ns80 <ns80> 2.10.1-1.mga10
+ Revision: 2066310
- new version 2.10.1 for java 21
+ neoclust <neoclust>
- Not maintained by java team

* Mon Aug 24 2020 neoclust <neoclust> 1.10-13.mga8
+ Revision: 1618325
- Fix build with java11
- Rebuild against java11

* Tue Feb 11 2020 umeabot <umeabot> 1.10-12.mga8
+ Revision: 1489258
- Mageia 8 Mass Rebuild

* Tue Sep 18 2018 umeabot <umeabot> 1.10-11.mga7
+ Revision: 1259542
- Mageia 7 Mass Rebuild

* Thu May 18 2017 neoclust <neoclust> 1.10-10.mga6
+ Revision: 1102921
- Rebuild against new apache-parent

* Wed Mar 02 2016 neoclust <neoclust> 1.10-9.mga6
+ Revision: 982440
- Second rebuild of the java stack

* Sun Feb 21 2016 neoclust <neoclust> 1.10-8.mga6
+ Revision: 975424
- First rebuild of the java stack
- sync package apache-commons-configuration with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Thu Dec 25 2014 pterjan <pterjan> 1.10-5.mga5
+ Revision: 805749
- Clean rebuild
- Sync with Fedora 21
+ dmorgan <dmorgan>
- Restore from Obsolete
+ sander85 <sander85>
- Depends on broken java stack

* Wed Oct 15 2014 umeabot <umeabot> 1.10-3.mga5
+ Revision: 741638
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.10-2.mga5
+ Revision: 677796
- Mageia 5 Mass Rebuild

* Sun Jun 15 2014 dmorgan <dmorgan> 1.10-1.mga5
+ Revision: 636424
- New version

* Tue Oct 22 2013 umeabot <umeabot> 1.9-6.mga4
+ Revision: 545622
- Mageia 4 Mass Rebuild

* Wed Oct 16 2013 dmorgan <dmorgan> 1.9-5.mga4
+ Revision: 501483
- Rebuild against new xml-commons-resolver

* Wed Oct 16 2013 dmorgan <dmorgan> 1.9-4.mga4
+ Revision: 501442
- Fix Buildrequires

* Thu Jul 11 2013 dmorgan <dmorgan> 1.9-3.mga4
+ Revision: 453189
- Build with xmvn

* Fri Jan 11 2013 umeabot <umeabot> 1.9-2.mga3
+ Revision: 345678
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Sep 12 2012 dmorgan <dmorgan> 1.9-1.mga3
+ Revision: 292626
- New version

* Mon Jul 16 2012 dmorgan <dmorgan> 1.6-7.mga3
+ Revision: 271316
- Update to current guidelines.
- Move to servlet 3.

* Wed Apr 27 2011 dmorgan <dmorgan> 1.6-6.mga1
+ Revision: 92227
- Rebuild after bootstrapping
- imported package apache-commons-configuration


* Tue Feb 15 2011 Stanislav Ochotnicky <sochotnicky@redhat.com> - 1.6-5
- Change ant dep groupId to org.apache.ant to fix build
- Versionless jar & javadocs
- Use maven 3 to build

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Oct 14 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 1.6-3
- tomcat5 -> tomcat6 BRs/Rs
- jakarta -> apache BRs/Rs

* Thu Jul  8 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 1.6-2
- Add license to javadoc subpackage

* Thu May 27 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 1.6-1
- Rename package (jakarta-commons-configuration->apache-commons-configuration)
- Build with maven instead of ant, drop deprecated patches
- Rebase, cleanups, drop epoch

* Thu Aug 20 2009 Alexander Kurtakov <akurtako@redhat.com> 0:1.4-7
- Fix description.
- Remove requires(post/postun) for javadoc subpackage.
- Use sed instead of dos2unix.

* Thu Aug 20 2009 Alexander Kurtakov <akurtako@redhat.com> 0:1.4-6
- Remove gcj support.
- Initial build for Fedora.

* Mon May 18 2009 Fernando Nasser <fnasser@redhat.com> - 0:1.4-5
- Fix license
- Fix source URL

* Wed Mar 18 2009 Yong Yang <yyang@redhat.com> - 0:1.4-4
- rebuild with new maven2 2.0.8 built in bootstrap mode

* Thu Feb 05 2009 Yong Yang <yyang@redhat.com> - 0:1.4-3
- Fix release tag

* Wed Jan 14 2009 Yong Yang <yyang@redhat.com> - 0:1.4-2jpp
- Import from dbhole's maven 2.0.8 packages, initial building

* Mon Aug 13 2007 Ralph Apel <r.apel at r-apel.de> - 0:1.4-1jpp
- Upgrade to 1.4
- Add pom file

* Thu May 03 2007 Ralph Apel <r.apel at r-apel.de> - 0:1.2-3jpp
- Patch one test

* Wed Mar 07 2007 Ralph Apel <r.apel at r-apel.de> - 0:1.2-2jpp
- Add gcj_support option
- Optionally build without maven

* Mon Feb 20 2006 Ralph Apel <r.apel at r-apel.de> - 0:1.2-1jpp
- Upgrade to 1.2

* Mon Feb 20 2006 Ralph Apel <r.apel at r-apel.de> - 0:1.1-2jpp
- Rebuild for JPP-1.7 and maven-1.1

* Thu Sep 15 2005 Ralph Apel <r.apel at r-apel.de> - 0:1.1-1jpp
- Upgrade to 1.1
- Omit findbugs and tasks reports: don't have these plugins yet
- Requires java 1.4.2 to build

* Mon Feb 21 2005 Ralph Apel <r.apel at r-apel.de> - 0:1.0.f-1jpp
- Upgrade to 1.0 final, letter in version can be bumped with 1.1
- Prepare for build with maven, but still build with ant

* Sun Aug 23 2004 Randy Watler <rwatler at finali.com> - 0:1.0.d3-2jpp
- Rebuild with ant-1.6.2
- Upgrade to Ant 1.6.X
* Mon Jan 19 2004 Ralph Apel <r.apel at r-apel.de> - 0:1.0.d3-1jpp
- First JPackage release
